autots.evaluator package
========================

Submodules
----------

autots.evaluator.auto\_model module
-----------------------------------

.. automodule:: autots.evaluator.auto_model
   :members:
   :undoc-members:
   :show-inheritance:

autots.evaluator.auto\_ts module
--------------------------------

.. automodule:: autots.evaluator.auto_ts
   :members:
   :undoc-members:
   :show-inheritance:

autots.evaluator.metrics module
-------------------------------

.. automodule:: autots.evaluator.metrics
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: autots.evaluator
   :members:
   :undoc-members:
   :show-inheritance:
